@@ -1,26 +1,26 @@
-#' Aggregate elemental price indexes
+#' Aggregate elementary price indexes
 #'
-#' Aggregate elemental price indexes with a price index aggregation structure.
+#' Aggregate elementary price indexes with a price index aggregation structure.
 #'
 #' The `aggregate()` method loops over each time period in `x` and
-#' 1. aggregates the elemental indexes with
+#' 1. aggregates the elementary indexes with
 #' [`gpindex::generalized_mean(r)()`][gpindex::generalized_mean] for each level
 #' of `pias`;
 #' 2. aggregates percent-change contributions for each level of
 #' `pias` (if there are any and `contrib = TRUE`);
 #' 3. price updates the weights in `pias` with
 #' [`gpindex::factor_weights(r)()`][gpindex::factor_weights] (only for
-#' period-over-period elemental indexes).
+#' period-over-period elementary indexes).
 #'
 #' The result is a collection of aggregated period-over-period indexes that
 #' can be chained together to get a fixed-base index when `x` are
-#' period-over-period elemental indexes. Otherwise, when `x` are fixed-base
-#' elemental indexes, the result is a collection of aggregated fixed-base
+#' period-over-period elementary indexes. Otherwise, when `x` are fixed-base
+#' elementary indexes, the result is a collection of aggregated fixed-base
 #' (direct) indexes.
 #'
-#' By default, missing elemental indexes will propagate when aggregating the
-#' index. Missing elemental indexes can be due to both missingness of these
-#' values in `x`, and the presence of elemental aggregates in `pias`
+#' By default, missing elementary indexes will propagate when aggregating the
+#' index. Missing elementary indexes can be due to both missingness of these
+#' values in `x`, and the presence of elementary aggregates in `pias`
 #' that are not part of `x`. Setting `na.rm = TRUE` ignores missing
 #' values, and is equivalent to parental (or overall mean) imputation. As an
 #' aggregated price index generally cannot have missing values (for otherwise
@@ -32,7 +32,7 @@
 #' this is detailed in chapter 8 (pp. 190--198) of the CPI manual (2020), with
 #' analogous details in chapter 9 of the PPI manual (2004).
 #' Aggregating with a non-arithmetic mean follows the same steps, except that
-#' the elemental indexes are aggregated with a mean of a different order (e.g.,
+#' the elementary indexes are aggregated with a mean of a different order (e.g.,
 #' harmonic for a Paasche index), and the method for price updating the weights
 #' is slightly different. Note that, because aggregation is done with a
 #' generalized mean, the resulting index is consistent-in-aggregation at each
@@ -44,8 +44,8 @@
 #' [`gpindex::transmute_weights(r, 1)()`][gpindex::transmute_weights] in order
 #' to apply this method.
 #'
-#' There may not be contributions for all prices relatives in an elemental
-#' aggregate if the elemental indexes are built from several sources (as with
+#' There may not be contributions for all prices relatives in an elementary
+#' aggregate if the elementary indexes are built from several sources (as with
 #' [`merge()`][merge.piar_index]). In this case the contribution for
 #' a price relative in the aggregated index will be correct, but the sum of all
 #' contributions will not equal the change in the value of the index. This can
@@ -64,7 +64,7 @@
 #' @name aggregate.piar_index
 #' @aliases aggregate.piar_index
 #'
-#' @param x A price index, usually made by [elemental_index()].
+#' @param x A price index, usually made by [elementary_index()].
 #' @param pias A price index aggregation structure or something that can be
 #'   coerced into one. This can be made with [aggregation_structure()].
 #' @param pias2 An optional secondary aggregation structure, usually with
@@ -73,17 +73,21 @@
 #'   are not removed. Setting `na.rm = TRUE` is equivalent to overall mean
 #'   imputation.
 #' @param r Order of the generalized mean to aggregate index values. 0 for a
-#'   geometric index (the default for making elemental indexes), 1 for an
-#'   arithmetic index (the default for aggregating elemental indexes and
+#'   geometric index (the default for making elementary indexes), 1 for an
+#'   arithmetic index (the default for aggregating elementary indexes and
 #'   averaging indexes over subperiods), or -1 for a harmonic index (usually for
 #'   a Paasche index). Other values are possible; see
 #'   [gpindex::generalized_mean()] for details. If `pias2` is given then the
 #'   index is aggregated with a quadratic mean of order `2*r`.
 #' @param contrib Aggregate percent-change contributions in `x` (if any)?
-#' @param include_ea Should indexes for the elemental aggregates be included
+#' @param include_ea Should indexes for the elementary aggregates be included
 #'   along with the aggregated indexes? By default, all index values are
 #'   returned.
 #' @param ... Not currently used.
+#' @param duplicate_contrib The method to deal with duplicate product
+#'   contributions. Either 'make.unique' to treat duplicate
+#'   products as distinct products and make their names unique
+#'   with [make.unique()] or 'sum' to add contributions for each product.
 #'
 #' @returns
 #' An aggregate price index that inherits from the class of `x`.
@@ -92,7 +96,7 @@
 #' For large indexes it can be much faster to turn the aggregation structure
 #' into an aggregation matrix with
 #' [`as.matrix()`][as.matrix.piar_aggregation_structure], then aggregate
-#' elemental indexes as a matrix operation when there are no missing
+#' elementary indexes as a matrix operation when there are no missing
 #' values. See the examples for details.
 #'
 #' @references
@@ -119,16 +123,17 @@
 #' # A two-level aggregation structure
 #'
 #' pias <- aggregation_structure(
-#'   list(c("top", "top", "top"), c("a", "b", "c")), weights = 1:3
+#'   list(c("top", "top", "top"), c("a", "b", "c")),
+#'   weights = 1:3
 #' )
 #'
-#' # Calculate Jevons elemental indexes
+#' # Calculate Jevons elementary indexes
 #'
-#' (elemental <- elemental_index(prices, rel ~ period + ea))
+#' (elementary <- elementary_index(prices, rel ~ period + ea))
 #'
-#' # Aggregate (note the imputation for elemental index 'c')
+#' # Aggregate (note the imputation for elementary index 'c')
 #'
-#' (index <- aggregate(elemental, pias, na.rm = TRUE))
+#' (index <- aggregate(elementary, pias, na.rm = TRUE))
 #'
 #' # Aggregation can equivalently be done as matrix multiplication
 #'
@@ -137,14 +142,17 @@
 #' @importFrom stats aggregate
 #' @family index methods
 #' @export
-aggregate.chainable_piar_index <- function(x,
-                                           pias,
-                                           ...,
-                                           pias2 = NULL,
-                                           na.rm = FALSE,
-                                           contrib = TRUE,
-                                           r = 1,
-                                           include_ea = TRUE) {
+aggregate.chainable_piar_index <- function(
+  x,
+  pias,
+  ...,
+  pias2 = NULL,
+  na.rm = FALSE,
+  contrib = TRUE,
+  r = 1,
+  include_ea = TRUE,
+  duplicate_contrib = c("make.unique", "sum")
+) {
   chkDots(...)
   aggregate_index(
     x,
@@ -154,20 +162,24 @@ aggregate.chainable_piar_index <- function(x,
     contrib = contrib,
     r = r,
     include_ea = include_ea,
-    chainable = TRUE
+    chainable = TRUE,
+    duplicate_contrib = duplicate_contrib
   )
 }
 
 #' @rdname aggregate.piar_index
 #' @export
-aggregate.direct_piar_index <- function(x,
-                                        pias,
-                                        ...,
-                                        pias2 = NULL,
-                                        na.rm = FALSE,
-                                        contrib = TRUE,
-                                        r = 1,
-                                        include_ea = TRUE) {
+aggregate.direct_piar_index <- function(
+  x,
+  pias,
+  ...,
+  pias2 = NULL,
+  na.rm = FALSE,
+  contrib = TRUE,
+  r = 1,
+  include_ea = TRUE,
+  duplicate_contrib = c("make.unique", "sum")
+) {
   chkDots(...)
   aggregate_index(
     x,
@@ -177,34 +189,65 @@ aggregate.direct_piar_index <- function(x,
     contrib = contrib,
     r = r,
     include_ea = include_ea,
-    chainable = FALSE
+    chainable = FALSE,
+    duplicate_contrib = duplicate_contrib
   )
 }
 
 #' Internal functions to aggregate a price index
 #' @noRd
-aggregate_index <- function(x,
-                            pias,
-                            pias2,
-                            na.rm,
-                            contrib,
-                            r,
-                            include_ea,
-                            chainable) {
+aggregate_index <- function(
+  x,
+  pias,
+  pias2,
+  na.rm,
+  contrib,
+  r,
+  include_ea,
+  chainable,
+  duplicate_contrib
+) {
   pias <- as_aggregation_structure(pias)
   r <- as.numeric(r)
   has_contrib <- has_contrib(x) && contrib
-  res <- aggregate_(x, pias, na.rm, has_contrib, r, include_ea, chainable)
+  res <- aggregate_(
+    x,
+    pias,
+    na.rm,
+    has_contrib,
+    r,
+    include_ea,
+    chainable,
+    duplicate_contrib
+  )
 
   if (!is.null(pias2)) {
     pias2 <- as_aggregation_structure(pias2)
-    if (!identical(pias[1:3], pias2[1:3])) {
+    if (!same_hierarchy(pias, pias2)) {
       stop("'pias' and 'pias2' must represent the same aggregation structure")
     }
-    res2 <- aggregate_(x, pias2, na.rm, has_contrib, -r, include_ea, chainable)
+    if (
+      any(missing_weights(pias$weights) != missing_weights(pias2$weights)) &&
+        contrib
+    ) {
+      stop(
+        "any NA or zero weights must appear in both 'pias' and 'pias2' when",
+        " 'contrib = TRUE'"
+      )
+    }
+    res2 <- aggregate_(
+      x,
+      pias2,
+      na.rm,
+      has_contrib,
+      -r,
+      include_ea,
+      chainable,
+      duplicate_contrib
+    )
     if (has_contrib) {
       res$contrib <- Map(
-        super_aggregate_contrib(),
+        super_aggregate_contrib(0),
         res$contrib,
         res2$contrib,
         res$index,
@@ -217,27 +260,36 @@ aggregate_index <- function(x,
   if (include_ea) {
     lev <- unlist(pias$levels, use.names = FALSE)
   } else {
-    lev <- unlist(pias$levels[-length(pias$levels)], use.names = FALSE)
+    lev <- unlist(drop_last(pias$levels), use.names = FALSE)
   }
 
   piar_index(res$index, res$contrib, lev, x$time, chainable)
 }
 
-aggregate_ <- function(x, pias, na.rm, has_contrib, r, include_ea, chainable) {
+aggregate_ <- function(
+  x,
+  pias,
+  na.rm,
+  has_contrib,
+  r,
+  include_ea,
+  chainable,
+  duplicate_contrib
+) {
   # Helpful functions.
   price_update <- gpindex::factor_weights(r)
   gen_mean <- gpindex::generalized_mean(r)
-  agg_contrib <- aggregate_contrib(r)
+  agg_contrib <- aggregate_contrib(r, duplicate_contrib)
 
   # Put the aggregation weights upside down to line up with pias.
   w <- rev(weights(pias, ea_only = FALSE, na.rm = na.rm))
 
-  eas <- match(pias$levels[[length(pias$levels)]], x$levels)
+  eas <- match_eas(pias, x)
 
   # Loop over each time period.
-  index <- contrib <- vector("list", length(x$time))
+  index <- contrib <- vector("list", ntime(x))
   for (t in seq_along(x$time)) {
-    rel <- con <- vector("list", length(pias$levels))
+    rel <- con <- vector("list", nlevels(pias))
     # Align epr with weights so that positional indexing works.
     rel[[1L]] <- x$index[[t]][eas]
     con[[1L]] <- x$contrib[[t]][eas]
@@ -294,13 +346,29 @@ aggregate_ <- function(x, pias, na.rm, has_contrib, r, include_ea, chainable) {
 #' @noRd
 # This function is inefficient because it recalculates the mean, but this
 # ensures that contributions are still produced with missing index values.
-aggregate_contrib <- function(r) {
+aggregate_contrib <- function(r, duplicate_contrib = c("make.unique", "sum")) {
   arithmetic_weights <- gpindex::transmute_weights(r, 1)
+  duplicate_contrib <- match.arg(duplicate_contrib)
   function(x, rel, w) {
     w <- arithmetic_weights(rel, w)
-    res <- unlist(Map(`*`, x, w))
-    if (length(res) > 0L) {
-      names(res) <- make.unique(as.character(names(res)))
+    res <- Map(`*`, x, w)
+    if (all(lengths(res) == 0L)) {
+      return(numeric(0L))
+    }
+    if (duplicate_contrib == "make.unique") {
+      res <- unlist(res)
+      names(res) <- make.unique(names(res))
+    } else {
+      products <- unlist(lapply(res, names), use.names = FALSE)
+      if (anyDuplicated(products)) {
+        products <- unique(products)
+        mat <- do.call(cbind, Map(`[`, res, list(products)))
+        res <- rowSums(mat, na.rm = TRUE)
+        res[apply(is.na(mat), 1, all)] <- NA
+        names(res) <- products
+      } else {
+        res <- unlist(res)
+      }
     }
     res
   }
@@ -308,8 +376,8 @@ aggregate_contrib <- function(r) {
 
 #' Aggregate product contributions for a superlative index
 #' @noRd
-super_aggregate_contrib <- function() {
-  arithmetic_weights <- gpindex::transmute_weights(0, 1)
+super_aggregate_contrib <- function(r) {
+  arithmetic_weights <- gpindex::transmute_weights(r, 1)
   Vectorize(
     function(x, y, rel1, rel2) {
       w <- arithmetic_weights(c(rel1, rel2))
