@@ -6,12 +6,12 @@
 #' [aggregation_structure()].
 #'
 #' The data frame and matrix methods treat `x` as a table with a row for
-#' each elemental aggregate, a column of labels for each level in the
-#' aggregation structure, and a column of weights for the elemental aggregates.
+#' each elementary aggregate, a column of labels for each level in the
+#' aggregation structure, and a column of weights for the elementary aggregates.
 #'
 #' @param x An object to coerce into an aggregation structure.
-#' @param weights A numeric vector of aggregation weights for the elemental
-#'   aggregates. The default is to give each elemental aggregate the same
+#' @param weights A numeric vector of aggregation weights for the elementary
+#'   aggregates. The default is to give each elementary aggregate the same
 #'   weight.
 #' @param ... Further arguments passed to or used by methods.
 #'
@@ -72,7 +72,7 @@ as_aggregation_structure.default <- function(x, ..., weights = NULL) {
 as_aggregation_structure.data.frame <- function(x, ...) {
   chkDots(...)
   x <- as.list(x)
-  aggregation_structure(x[-length(x)], x[[length(x)]])
+  aggregation_structure(drop_last(x), last(x))
 }
 
 #' @rdname as_aggregation_structure
