@@ -2,7 +2,7 @@
 #'
 #' Extract and replace index values over a window of time periods.
 #'
-#' @param x A price index, as made by, e.g., [elemental_index()].
+#' @param x A price index, as made by, e.g., [elementary_index()].
 #' @param start The time period to start the window. The default in the first
 #'   period of `x`.
 #' @param end The time period to end the window. The default is the last period
@@ -43,10 +43,14 @@ window.piar_index <- function(x, start = NULL, end = NULL, ...) {
 #' Get the indexes for a window of time periods
 #' @noRd
 index_window <- function(x, start, end) {
-  if (is.null(start)) start <- start(x)
-  if (is.null(end)) end <- end(x)
-  start <- match_time(as.character(start), x$time)
-  end <- match_time(as.character(end), x$time)
+  if (is.null(start)) {
+    start <- start(x)
+  }
+  if (is.null(end)) {
+    end <- end(x)
+  }
+  start <- match_time(as.character(start), x)
+  end <- match_time(as.character(end), x)
 
   if (start > end) {
     stop("'start' must refer to a time period before 'end'")
